#pragma once

#include "LibLsp/JsonRpc/serializer.h"
#include "LibLsp/JsonRpc/message.h"
#include "LibLsp/lsp/lsCodeAction.h"
#include "LibLsp/lsp/workspace/execute_command.h"
#include <set>
#include "LibLsp/lsp/textDocument/code_action.h"

namespace SourceAssistProcessor
{

/*std::set<std::string> UNSUPPORTED_RESOURCES = { "module-info.java", "package-info.java"
        };*/

//      static  const char* COMMAND_ID_ACTION_OVERRIDEMETHODSPROMPT = "java.action.overrideMethodsPrompt";
//      static  const char* COMMAND_ID_ACTION_HASHCODEEQUALSPROMPT = "java.action.hashCodeEqualsPrompt";
//      static  const char* COMMAND_ID_ACTION_ORGANIZEIMPORTS = "java.action.organizeImports";
//      static  const char* COMMAND_ID_ACTION_GENERATETOSTRINGPROMPT = "java.action.generateToStringPrompt";
//      static  const char* COMMAND_ID_ACTION_GENERATEACCESSORSPROMPT = "java.action.generateAccessorsPrompt";
//      static  const char* COMMAND_ID_ACTION_GENERATECONSTRUCTORSPROMPT = "java.action.generateConstructorsPrompt";
//      static  const char* COMMAND_ID_ACTION_GENERATEDELEGATEMETHODSPROMPT = "java.action.generateDelegateMethodsPrompt";
}; // namespace SourceAssistProcessor
